==> alone-frame-2.0.3.tgz: package/frame/plugin.js <==
import {NaiveUiResolver} from "unplugin-vue-components/dist/resolvers.js";

import components from 'unplugin-vue-components/vite';

import viteCompression from "vite-plugin-compression";

import {nodes, is_mac, zip_file} from "../nodes.js";

import autoImport from "unplugin-auto-import/vite";

import {createHtmlPlugin} from "vite-plugin-html";

import markdown from 'unplugin-vue-markdown/vite';

import {viteMockServe} from "vite-plugin-mock";

import svgLoader from "vite-svg-loader";

import frameConfig from "./config.js";

import vue from "@vitejs/plugin-vue";

import alone from "../alone.js";

export default async function (pathname, option = {}, plugins = null) {
    const then = await frameConfig(pathname, alone.is_object(option) ? option : (alone.is_object(plugins) ? plugins : {}));
    const self = {
        plugin: {
            vue(data) {
                return vue(alone.array_merge({include: [/\.vue$/, /\.md$/]}, data));
            },
            html(data) {
                const tags = alone.get_arr(data, 'inject.tags');
                const config = alone.array_merge(data, {minify: true, inject: {tags: []}});
                config.inject.tags = (alone.isset(tags) && alone.is_array(tags)) ? then.html_tag.concat(tags) : then.html_tag;
                config.entry = then.option.main;
                return createHtmlPlugin(config);
            },
            auto(data) {
                return autoImport(alone.array_merge({
                    dts: then.env.dts.auto || false,
                    imports: ['vue', {
                        'naive-ui': [
                            'useDialog',
                            'useMessage',
                            'useNotification',
                            'useLoadingBar'
                        ]
                    }]
                }, data || {}));
            },
            compress(data) {
                return viteCompression(alone.array_merge({
                    verbose: true,    // 默认即可
                    disable: true,  //开启压缩(不禁用)，默认即可
                    deleteOriginFile: false, //删除源文件
                    threshold: 10240, //压缩前最小文件大小
                    algorithm: 'gzip',  //压缩算法
                    ext: '.gz', //文件类型
                }, data));
            },
            svg(data) {
                return svgLoader(alone.array_merge({defaultImport: 'url'}, data));
            },
            md(data) {
                const config = {headEnabled: true, markdownItOptions: {html: true, linkify: true, typographer: true}};
                const include = [`${then.node.get_path('.')}/*.md`, `${then.node.get_path('.')}/**/*.md`];
                const includes = alone.get_arr(data, 'include');
                config.include = (alone.isset(includes) && alone.is_array(includes)) ? include.concat(includes) : include;
                return markdown(config);
            },
            mock(data) {
                if (!then.env.mock) return {};
                return viteMockServe(alone.array_merge({
                    mockPath: then.env.mock,//存放 Mock 文件的路径。默认情况下，插件会在此路径下查找 Mock 文件
                    watchFiles: true,//指示是否监视 Mock 文件的变化。如果设置为 true，当 Mock 文件发生变化时，Mock 服务器会自动更新。
                    enable: true,//指示是否启用 Mock 功能。设置为 false 可以临时禁用 Mock。
                    logger: false,//指示是否启用插件的日志记录。设置为 true 会在终端输出 Mock 请求的日志信息。
                    cors: true //指示是否启用 CORS（跨域资源共享）。设置为 true 会在响应中添加 CORS 头部，以允许跨域请求。
                }, data || {}));
            },
            component(data) {
                return components(alone.array_merge({
                    dts: then.env.dts.component || false,
                    extensions: ['vue', 'md'],
                    include: [/\.vue$/, /\.vue\?vue/, /\.md$/],
                    resolvers: [NaiveUiResolver()],
                }, data || {}));
            },
            //设置配置
            alone_config() {
                return {
                    enforce: 'pre',
                    name: 'alone-config',
                    config(config) {
                        config.root = then.app_path;
                        config.base = config.base || "./";
                        config.publicDir = then.publicDir();
                        config.resolve = config.resolve || {};
                        config.define = alone.array_merge(config.define, then.define());
                        config.resolve.alias = alone.array_merge(config.resolve.alias, then.alias());
                        config.build = alone.array_merge(config.build, then.plugin_build());
                        config.preview = alone.array_merge(config.preview, then.preview());
                        config.server = alone.array_merge(config.server, then.server());
                    }
                };
            },
            //加载main
            alone_main() {
                return {
                    enforce: 'pre',
                    name: 'alone-main',
                    transform(code, file) {
                        const beforeCode = `
            import MainLoadBefore from "alone-frame/frame/main";
            MainLoadBefore.status = {};
            await MainLoadBefore.load();
            `;
                        const afterCode = `
            import MainLoadAfter from "alone-frame/frame/main";
            MainLoadAfter.mount();
            `;
                        return then.plugin_transform_main(code, file, beforeCode, afterCode);
                    }
                };
            },
            //显示
            alone_show() {
                return {
                    enforce: 'post',
                    name: 'alone-show',
                    buildStart() {
                        console.log('path', `${is_mac() ? "file://" : ""}${then.app.get_path('.')}`);
                    },
                    closeBundle() {
                        console.log('complete', `${is_mac() ? "file://" : ""}` + then.out_dir);
                    }
                };
            },
            //路由
            alone_route() {
                return {
                    enforce: 'pre',
                    name: 'alone-route',
                    buildStart() {
                        then.vue_route();
                    }
                };
            },
            alone_build() {
                return {
                    enforce: 'post',
                    apply: 'build',
                    name: 'alone-build',
                    buildStart() {
                        nodes(then.out_dir).del_dir_file('.', then.env.exclude);
                    },
                    closeBundle() {
                        nodes(then.out_dir).delete_file('layui/lay.js');
                        if (then.env.zip === true) {
                            zip_file(then.out_dir, alone.rtrim(then.out_dir, '/') + ".zip", function (size, unit, file) {
                                console.log('zip file', file);
                                console.log('zip size', `${size}${unit}`);
                            });
                        }
                    }
                };
            }
        },
        load: {},
        list: {},
        plugins: [],
        call: (alone.is_callback(plugins) ? plugins : (alone.is_callback(option) ? option : (() => null))),
        start(type) {
            this.method = Object.keys(this.plugin).reduce((acc, key) => {
                acc[key] = function (data) {
                    return {plugin_name: key, ['plugin_' + key]: data};
                };
                return acc;
            }, {});
            this.custom = this.call.bind(then)(this.method);
            return this.deal(type);
        },
        getPlugin() {
            return Object.values(this.plugin).map(method => method());
        },
        deal(type) {
            if (type !== true && alone.isset(this.custom) && alone.is_array(this.custom)) {
                this.custom.forEach((val, key) => {
                    const name = val.plugin_name;
                    if (name && this.plugin.hasOwnProperty(name)) {
                        this.list[name] = true;
                        const value = val['plugin_' + name];
                        if (value !== false) {
                            this.load[key] = (this.plugin[name])(value);
                        }
                    } else {
                        this.load[key] = val;
                    }
                });
                if (alone.isset(this.list)) {
                    Object.keys(this.method).forEach((key) => {
                        if (!this.list.hasOwnProperty(key)) {
                            this.plugins.push(this.plugin[key]())
                        }
                    });
                } else {
                    this.plugins = this.getPlugin();
                }
                if (alone.isset(this.load)) {
                    Object.keys(this.load).forEach((key) => {
                        this.plugins.push(this.load[key]);
                    });
                }
            } else {
                this.plugins = this.getPlugin();
            }
            return this.plugins;
        }
    };
    return self.start();
}

==> alone-frame-2.0.4.tgz: package/frame/plugin.js <==
import {NaiveUiResolver} from "unplugin-vue-components/dist/resolvers.js";

import components from 'unplugin-vue-components/vite';

import viteCompression from "vite-plugin-compression";

import {nodes, is_mac, zip_file} from "../nodes.js";

import {delView} from "alone-frame/route/setVue.js";

import autoImport from "unplugin-auto-import/vite";

import {createHtmlPlugin} from "vite-plugin-html";

import markdown from 'unplugin-vue-markdown/vite';

import {viteMockServe} from "vite-plugin-mock";

import svgLoader from "vite-svg-loader";

import frameConfig from "./config.js";

import vue from "@vitejs/plugin-vue";

import alone from "../alone.js";

export default async function (pathname, option = {}, plugins = null) {
    const then = await frameConfig(pathname, alone.is_object(option) ? option : (alone.is_object(plugins) ? plugins : {}));
    const self = {
        plugin: {
            vue(data) {
                return vue(alone.array_merge({include: [/\.vue$/, /\.md$/]}, data));
            },
            html(data) {
                const tags = alone.get_arr(data, 'inject.tags');
                const config = alone.array_merge(data, {minify: true, inject: {tags: []}});
                config.inject.tags = (alone.isset(tags) && alone.is_array(tags)) ? then.html_tag.concat(tags) : then.html_tag;
                config.entry = then.option.main;
                return createHtmlPlugin(config);
            },
            auto(data) {
                return autoImport(alone.array_merge({
                    dts: then.env.dts.auto || false,
                    imports: ['vue', {
                        'naive-ui': [
                            'useDialog',
                            'useMessage',
                            'useNotification',
                            'useLoadingBar'
                        ]
                    }]
                }, data || {}));
            },
            compress(data) {
                return viteCompression(alone.array_merge({
                    verbose: true,    // 默认即可
                    disable: true,  //开启压缩(不禁用)，默认即可
                    deleteOriginFile: false, //删除源文件
                    threshold: 10240, //压缩前最小文件大小
                    algorithm: 'gzip',  //压缩算法
                    ext: '.gz', //文件类型
                }, data));
            },
            svg(data) {
                return svgLoader(alone.array_merge({defaultImport: 'url'}, data));
            },
            md(data) {
                const config = {headEnabled: true, markdownItOptions: {html: true, linkify: true, typographer: true}};
                const include = [`${then.node.get_path('.')}/*.md`, `${then.node.get_path('.')}/**/*.md`];
                const includes = alone.get_arr(data, 'include');
                config.include = (alone.isset(includes) && alone.is_array(includes)) ? include.concat(includes) : include;
                return markdown(config);
            },
            mock(data) {
                if (!then.env.mock) return {};
                return viteMockServe(alone.array_merge({
                    mockPath: then.env.mock,//存放 Mock 文件的路径。默认情况下，插件会在此路径下查找 Mock 文件
                    watchFiles: true,//指示是否监视 Mock 文件的变化。如果设置为 true，当 Mock 文件发生变化时，Mock 服务器会自动更新。
                    enable: true,//指示是否启用 Mock 功能。设置为 false 可以临时禁用 Mock。
                    logger: false,//指示是否启用插件的日志记录。设置为 true 会在终端输出 Mock 请求的日志信息。
                    cors: true //指示是否启用 CORS（跨域资源共享）。设置为 true 会在响应中添加 CORS 头部，以允许跨域请求。
                }, data || {}));
            },
            component(data) {
                return components(alone.array_merge({
                    dts: then.env.dts.component || false,
                    extensions: ['vue', 'md'],
                    include: [/\.vue$/, /\.vue\?vue/, /\.md$/],
                    resolvers: [NaiveUiResolver()],
                }, data || {}));
            },
            //设置配置
            alone_config() {
                return {
                    enforce: 'pre',
                    name: 'alone-config',
                    config(config) {
                        config.root = then.app_path;
                        config.base = config.base || "./";
                        config.publicDir = then.publicDir();
                        config.resolve = config.resolve || {};
                        config.define = alone.array_merge(config.define, then.define());
                        config.resolve.alias = alone.array_merge(config.resolve.alias, then.alias());
                        config.build = alone.array_merge(config.build, then.plugin_build());
                        config.preview = alone.array_merge(config.preview, then.preview());
                        config.server = alone.array_merge(config.server, then.server());
                    }
                };
            },
            //加载main
            alone_main() {
                return {
                    enforce: 'pre',
                    name: 'alone-main',
                    transform(code, file) {
                        const beforeCode = `
            import MainLoadBefore from "alone-frame/frame/main";
            MainLoadBefore.status = {};
            await MainLoadBefore.load();
            `;
                        const afterCode = `
            import MainLoadAfter from "alone-frame/frame/main";
            MainLoadAfter.mount();
            `;
                        return then.plugin_transform_main(code, file, beforeCode, afterCode);
                    }
                };
            },
            //显示
            alone_show() {
                return {
                    enforce: 'post',
                    name: 'alone-show',
                    buildStart() {
                        console.log('path', `${is_mac() ? "file://" : ""}${then.app.get_path('.')}`);
                    },
                    closeBundle() {
                        console.log('complete', `${is_mac() ? "file://" : ""}` + then.out_dir);
                    }
                };
            },
            //路由
            alone_route() {
                return {
                    enforce: 'pre',
                    name: 'alone-route',
                    buildStart() {
                        then.vue_route();
                    }
                };
            },
            alone_build() {
                return {
                    enforce: 'post',
                    apply: 'build',
                    name: 'alone-build',
                    buildStart() {
                        nodes(then.out_dir).del_dir_file('.', then.env.exclude);
                    },
                    closeBundle() {
                        nodes(then.out_dir).delete_file('layui/lay.js');
                        if (then.env.zip === true) {
                            zip_file(then.out_dir, alone.rtrim(then.out_dir, '/') + ".zip", function (size, unit, file) {
                                console.log('zip file', file);
                                console.log('zip size', `${size}${unit}`);
                            });
                        }
                    }
                };
            }
        },
        load: {},
        list: {},
        plugins: [],
        call: (alone.is_callback(plugins) ? plugins : (alone.is_callback(option) ? option : (() => null))),
        start(type) {
            this.method = Object.keys(this.plugin).reduce((acc, key) => {
                acc[key] = function (data) {
                    return {plugin_name: key, ['plugin_' + key]: data};
                };
                return acc;
            }, {});
            this.custom = this.call.bind(then)(this.method);
            return this.deal(type);
        },
        getPlugin() {
            return Object.values(this.plugin).map(method => method());
        },
        deal(type) {
            if (type !== true && alone.isset(this.custom) && alone.is_array(this.custom)) {
                this.custom.forEach((val, key) => {
                    const name = val.plugin_name;
                    if (name && this.plugin.hasOwnProperty(name)) {
                        const value = val['plugin_' + name];
                        this.list[name] = value;
                        if (value !== false) {
                            this.load[key] = (this.plugin[name])(value);
                        }
                    } else {
                        this.load[key] = val;
                    }
                });
                if (this.list.alone_route === false) {
                    delView();
                }
                if (alone.isset(this.list)) {
                    Object.keys(this.method).forEach((key) => {
                        if (!this.list.hasOwnProperty(key)) {
                            this.plugins.push(this.plugin[key]())
                        }
                    });
                } else {
                    this.plugins = this.getPlugin();
                }
                if (alone.isset(this.load)) {
                    Object.keys(this.load).forEach((key) => {
                        this.plugins.push(this.load[key]);
                    });
                }
            } else {
                this.plugins = this.getPlugin();
            }
            return this.plugins;
        }
    };
    return self.start();
}
